@@ -3,6 +3,22 @@
 #
 confint <- function(object, parm, level = 0.95, ...) UseMethod("confint")
 
+confint.lm <- function(object, parm, level = 0.95, ...)
+{
+    pnames <- names(coef(object))
+    if(missing(parm)) parm <- seq(along=pnames)
+    else if(is.character(parm))  parm <- match(parm, pnames, nomatch = 0)
+    a <- (1-level)/2
+    a <- c(a, 1-a)
+    pct <- paste(round(100*a, 1), "%")
+    ci <- array(NA, dim = c(length(parm), 2),
+                dimnames = list(pnames[parm], pct))
+    ses <- sqrt(diag(vcov(object)))
+    fac <- qt(a, object$df.residual)
+    ci[] <- object$coefficients + ses %o% fac
+    ci
+}
+
 confint.glm <- function(object, parm, level = 0.95, trace = FALSE, ...)
 {
     pnames <- names(coef(object))
@@ -29,8 +45,8 @@ confint.profile.glm <-
     for(pm in parm) {
         pro <- object[[pm]]
         if(length(pnames) > 1)
-            sp <- spline(x = pro[, "par.vals"][, pm], y = pro$z)
-        else sp <- spline(x = pro[, "par.vals"], y = pro$z)
+            sp <- spline(x = pro[, "par.vals"][, pm], y = pro$tau)
+        else sp <- spline(x = pro[, "par.vals"], y = pro$tau)
         ci[pnames[pm], ] <- approx(sp$y, sp$x, xout = cutoff)$y
     }
     drop(ci)
